package com.srs.routine.mapper;

import java.util.List;

import com.srs.routine.domain.RtEnlistmentReserveApproval;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import org.apache.ibatis.annotations.Param;

/**
 * 保留学籍审批记录Mapper接口
 *
 * @author srs
 * @date 2025-11-13
 */
public interface RtEnlistmentReserveApprovalMapper extends BaseMapper<RtEnlistmentReserveApproval> {
    /**
     * 查询保留学籍审批记录
     *
     * @param id 保留学籍审批记录主键
     * @return 保留学籍审批记录
     */
    public RtEnlistmentReserveApproval selectRtEnlistmentReserveApprovalById(Long id);

    /**
     * 查询保留学籍审批记录列表
     *
     * @param rtEnlistmentReserveApproval 保留学籍审批记录
     * @return 保留学籍审批记录集合
     */
    List<RtEnlistmentReserveApproval> selectRtEnlistmentReserveApprovalList(RtEnlistmentReserveApproval rtEnlistmentReserveApproval);

    /**
     * 新增保留学籍审批记录
     *
     * @param rtEnlistmentReserveApproval 保留学籍审批记录
     * @return 结果
     */
    int insertRtEnlistmentReserveApproval(RtEnlistmentReserveApproval rtEnlistmentReserveApproval);

    /**
     * 修改保留学籍审批记录
     *
     * @param rtEnlistmentReserveApproval 保留学籍审批记录
     * @return 结果
     */
    int updateRtEnlistmentReserveApproval(RtEnlistmentReserveApproval rtEnlistmentReserveApproval);

    /**
     * 删除保留学籍审批记录
     *
     * @param id 保留学籍审批记录主键
     * @return 结果
     */
    int deleteRtEnlistmentReserveApprovalById(Long id);

    /**
     * 根据学生姓名学号和审批人id查询保留学籍审批记录
     *
     * @param
     * @return 结果
     */
    RtEnlistmentReserveApproval selectRtEnlistmentReserveApprovalByStuName(@Param("studentName") String studentName, @Param("studentNo") String studentNo, @Param("approverId") Long approverId);

    /**
     * 批量删除保留学籍审批记录
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteRtEnlistmentReserveApprovalByIds(Long[] ids);
}
